BaseVfsFile class abstract Cross-platform definitions

A VirtualFileSystemFile base class that implements xRead to zero-fill the buffer in case of short reads.

Implemented types

Constructors

BaseVfsFile()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xDeviceCharacteristics int
Returns a bitvector of device flags.
no setteroverride
xSectorSize int
The sector size of the device that underlies the file.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readInto(Uint8List buffer, int offset) int
Reads from the file at offset into the buffer and returns the amount of bytes read.
toString() String
A string representation of this object.
inherited
xCheckReservedLock() int
Returns the lock state held by any process on this file.
inherited
xClose() → void
Close this file.
inherited
xFileControl(int op, int ptr) int
Handle a file control request with the given operand and pointer (represented as its address to avoid a dart:ffi import in common code).
override
xFileSize() int
Returns the size of this file.
inherited
xLock(int mode) → void
Moves the lock state of this file to a more exclusive lock state.
inherited
xRead(Uint8List target, int fileOffset) → void
Fill the target with bytes read from fileOffset.
override
xSync(int flags) → void
Synchronizes, or flushes, the contents of this file to the file system.
inherited
xTruncate(int size) → void
Truncates this file to a size of size.
inherited
xUnlock(int mode) → void
Moves the lock state of this file to a less exclusive lock state.
inherited
xWrite(Uint8List buffer, int fileOffset) → void
Writes the buffer into this file at fileOffset, overwriting existing content or appending to it.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited