createImportObject method

JSObject createImportObject()

Creates a JavaScript object providing definitions used as imported functions by the WebAssembly module.

The default build uses the dart namespace to import definitions provided by the sqlite3 package. Custom builds might need additional functions, which can be provided by overriding this method to install additional namespaces.

Implementation

JSObject createImportObject() {
  return JSObject()..['dart'] = createJSInteropWrapper(_dartFunctions);
}