Utility to load sqlite3.wasm files.
This class can be extended to inject additional host functions into loaded modules.
- Annotations
-
- @experimental
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createImportObject(
) → JSObject - Creates a JavaScript object providing definitions used as imported functions by the WebAssembly module.
-
instantiateModule(
Response response) → Future< WebAssemblyInstantiatedSource> -
Instantiates a module by calling
WebAssembly.instantiateStreamingwith the response and createImportObject. -
loadModule(
Response response) → Future< Instance> - Load and instantiate a WebAssembly module from a fetch response by providing host imports.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited